==> zio-aws-textract_3-5.17.153.1-sources.jar: zio/aws/textract/model/GetDocumentAnalysisResponse.scala <==
package zio.aws.textract.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.textract.model.primitives.{StatusMessage, PaginationToken}
import scala.jdk.CollectionConverters.*
final case class GetDocumentAnalysisResponse(
    documentMetadata: Option[zio.aws.textract.model.DocumentMetadata] = None,
    jobStatus: Option[zio.aws.textract.model.JobStatus] = None,
    nextToken: Option[PaginationToken] = None,
    blocks: Option[Iterable[zio.aws.textract.model.Block]] = None,
    warnings: Option[Iterable[zio.aws.textract.model.Warning]] = None,
    statusMessage: Option[StatusMessage] = None,
    analyzeDocumentModelVersion: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.textract.model.GetDocumentAnalysisResponse = {
    import GetDocumentAnalysisResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.textract.model.GetDocumentAnalysisResponse
      .builder()
      .optionallyWith(documentMetadata.map(value => value.buildAwsValue()))(
        _.documentMetadata
      )
      .optionallyWith(jobStatus.map(value => value.unwrap))(_.jobStatus)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        blocks.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.blocks)
      .optionallyWith(
        warnings.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.warnings)
      .optionallyWith(
        statusMessage.map(value =>
          StatusMessage.unwrap(value): java.lang.String
        )
      )(_.statusMessage)
      .optionallyWith(
        analyzeDocumentModelVersion.map(value => value: java.lang.String)
      )(_.analyzeDocumentModelVersion)
      .build()
  }
  def asReadOnly: zio.aws.textract.model.GetDocumentAnalysisResponse.ReadOnly =
    zio.aws.textract.model.GetDocumentAnalysisResponse.wrap(buildAwsValue())
}
object GetDocumentAnalysisResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.textract.model.GetDocumentAnalysisResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.textract.model.GetDocumentAnalysisResponse =
      zio.aws.textract.model.GetDocumentAnalysisResponse(
        documentMetadata.map(value => value.asEditable),
        jobStatus.map(value => value),
        nextToken.map(value => value),
        blocks.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        warnings.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        statusMessage.map(value => value),
        analyzeDocumentModelVersion.map(value => value)
      )
    def documentMetadata
        : Option[zio.aws.textract.model.DocumentMetadata.ReadOnly]
    def jobStatus: Option[zio.aws.textract.model.JobStatus]
    def nextToken: Option[PaginationToken]
    def blocks: Option[List[zio.aws.textract.model.Block.ReadOnly]]
    def warnings: Option[List[zio.aws.textract.model.Warning.ReadOnly]]
    def statusMessage: Option[StatusMessage]
    def analyzeDocumentModelVersion: Option[String]
    def getDocumentMetadata
        : ZIO[Any, AwsError, zio.aws.textract.model.DocumentMetadata.ReadOnly] =
      AwsError.unwrapOptionField("documentMetadata", documentMetadata)
    def getJobStatus: ZIO[Any, AwsError, zio.aws.textract.model.JobStatus] =
      AwsError.unwrapOptionField("jobStatus", jobStatus)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getBlocks
        : ZIO[Any, AwsError, List[zio.aws.textract.model.Block.ReadOnly]] =
      AwsError.unwrapOptionField("blocks", blocks)
    def getWarnings
        : ZIO[Any, AwsError, List[zio.aws.textract.model.Warning.ReadOnly]] =
      AwsError.unwrapOptionField("warnings", warnings)
    def getStatusMessage: ZIO[Any, AwsError, StatusMessage] =
      AwsError.unwrapOptionField("statusMessage", statusMessage)
    def getAnalyzeDocumentModelVersion: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField(
        "analyzeDocumentModelVersion",
        analyzeDocumentModelVersion
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.textract.model.GetDocumentAnalysisResponse
  ) extends zio.aws.textract.model.GetDocumentAnalysisResponse.ReadOnly {
    override val documentMetadata
        : Option[zio.aws.textract.model.DocumentMetadata.ReadOnly] = scala
      .Option(impl.documentMetadata())
      .map(value => zio.aws.textract.model.DocumentMetadata.wrap(value))
    override val jobStatus: Option[zio.aws.textract.model.JobStatus] = scala
      .Option(impl.jobStatus())
      .map(value => zio.aws.textract.model.JobStatus.wrap(value))
    override val nextToken: Option[PaginationToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.textract.model.primitives.PaginationToken(value))
    override val blocks: Option[List[zio.aws.textract.model.Block.ReadOnly]] =
      scala
        .Option(impl.blocks())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.textract.model.Block.wrap(item)
          }.toList
        )
    override val warnings
        : Option[List[zio.aws.textract.model.Warning.ReadOnly]] = scala
      .Option(impl.warnings())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.textract.model.Warning.wrap(item)
        }.toList
      )
    override val statusMessage: Option[StatusMessage] = scala
      .Option(impl.statusMessage())
      .map(value => zio.aws.textract.model.primitives.StatusMessage(value))
    override val analyzeDocumentModelVersion: Option[String] = scala
      .Option(impl.analyzeDocumentModelVersion())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.textract.model.GetDocumentAnalysisResponse
  ): zio.aws.textract.model.GetDocumentAnalysisResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-textract_3-5.19.7.4-sources.jar: zio/aws/textract/model/GetDocumentAnalysisResponse.scala <==
package zio.aws.textract.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.textract.model.primitives.{StatusMessage, PaginationToken}
import scala.jdk.CollectionConverters.*
final case class GetDocumentAnalysisResponse(
    documentMetadata: Optional[zio.aws.textract.model.DocumentMetadata] =
      Optional.Absent,
    jobStatus: Optional[zio.aws.textract.model.JobStatus] = Optional.Absent,
    nextToken: Optional[PaginationToken] = Optional.Absent,
    blocks: Optional[Iterable[zio.aws.textract.model.Block]] = Optional.Absent,
    warnings: Optional[Iterable[zio.aws.textract.model.Warning]] =
      Optional.Absent,
    statusMessage: Optional[StatusMessage] = Optional.Absent,
    analyzeDocumentModelVersion: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.textract.model.GetDocumentAnalysisResponse = {
    import GetDocumentAnalysisResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.textract.model.GetDocumentAnalysisResponse
      .builder()
      .optionallyWith(documentMetadata.map(value => value.buildAwsValue()))(
        _.documentMetadata
      )
      .optionallyWith(jobStatus.map(value => value.unwrap))(_.jobStatus)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        blocks.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.blocks)
      .optionallyWith(
        warnings.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.warnings)
      .optionallyWith(
        statusMessage.map(value =>
          StatusMessage.unwrap(value): java.lang.String
        )
      )(_.statusMessage)
      .optionallyWith(
        analyzeDocumentModelVersion.map(value => value: java.lang.String)
      )(_.analyzeDocumentModelVersion)
      .build()
  }
  def asReadOnly: zio.aws.textract.model.GetDocumentAnalysisResponse.ReadOnly =
    zio.aws.textract.model.GetDocumentAnalysisResponse.wrap(buildAwsValue())
}
object GetDocumentAnalysisResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.textract.model.GetDocumentAnalysisResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.textract.model.GetDocumentAnalysisResponse =
      zio.aws.textract.model.GetDocumentAnalysisResponse(
        documentMetadata.map(value => value.asEditable),
        jobStatus.map(value => value),
        nextToken.map(value => value),
        blocks.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        warnings.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        statusMessage.map(value => value),
        analyzeDocumentModelVersion.map(value => value)
      )
    def documentMetadata
        : Optional[zio.aws.textract.model.DocumentMetadata.ReadOnly]
    def jobStatus: Optional[zio.aws.textract.model.JobStatus]
    def nextToken: Optional[PaginationToken]
    def blocks: Optional[List[zio.aws.textract.model.Block.ReadOnly]]
    def warnings: Optional[List[zio.aws.textract.model.Warning.ReadOnly]]
    def statusMessage: Optional[StatusMessage]
    def analyzeDocumentModelVersion: Optional[String]
    def getDocumentMetadata
        : ZIO[Any, AwsError, zio.aws.textract.model.DocumentMetadata.ReadOnly] =
      AwsError.unwrapOptionField("documentMetadata", documentMetadata)
    def getJobStatus: ZIO[Any, AwsError, zio.aws.textract.model.JobStatus] =
      AwsError.unwrapOptionField("jobStatus", jobStatus)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getBlocks
        : ZIO[Any, AwsError, List[zio.aws.textract.model.Block.ReadOnly]] =
      AwsError.unwrapOptionField("blocks", blocks)
    def getWarnings
        : ZIO[Any, AwsError, List[zio.aws.textract.model.Warning.ReadOnly]] =
      AwsError.unwrapOptionField("warnings", warnings)
    def getStatusMessage: ZIO[Any, AwsError, StatusMessage] =
      AwsError.unwrapOptionField("statusMessage", statusMessage)
    def getAnalyzeDocumentModelVersion: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField(
        "analyzeDocumentModelVersion",
        analyzeDocumentModelVersion
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.textract.model.GetDocumentAnalysisResponse
  ) extends zio.aws.textract.model.GetDocumentAnalysisResponse.ReadOnly {
    override val documentMetadata
        : Optional[zio.aws.textract.model.DocumentMetadata.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.documentMetadata())
        .map(value => zio.aws.textract.model.DocumentMetadata.wrap(value))
    override val jobStatus: Optional[zio.aws.textract.model.JobStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.jobStatus())
        .map(value => zio.aws.textract.model.JobStatus.wrap(value))
    override val nextToken: Optional[PaginationToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.textract.model.primitives.PaginationToken(value))
    override val blocks: Optional[List[zio.aws.textract.model.Block.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.blocks())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.textract.model.Block.wrap(item)
          }.toList
        )
    override val warnings
        : Optional[List[zio.aws.textract.model.Warning.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.warnings())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.textract.model.Warning.wrap(item)
          }.toList
        )
    override val statusMessage: Optional[StatusMessage] = zio.aws.core.internal
      .optionalFromNullable(impl.statusMessage())
      .map(value => zio.aws.textract.model.primitives.StatusMessage(value))
    override val analyzeDocumentModelVersion: Optional[String] =
      zio.aws.core.internal
        .optionalFromNullable(impl.analyzeDocumentModelVersion())
        .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.textract.model.GetDocumentAnalysisResponse
  ): zio.aws.textract.model.GetDocumentAnalysisResponse.ReadOnly = new Wrapper(
    impl
  )
}
